#!/usr/bin/python
# -*- coding: UTF-8 -*-
# @Time    : 2023/4/20 03:38
# @Author  : 心蓝
# @email   : 117220100@qq.com
# @微信号  : hhxpython
from .core import TestProgram


def tools():
    TestProgram().execute()
